==> tencentcloud-sdk-java-3.1.900-sources.jar: com/tencentcloudapi/redis/v20180412/models/HotKeyInfo.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.redis.v20180412.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class HotKeyInfo extends AbstractModel {

    /**
    * 热Key
    */
    @SerializedName("Key")
    @Expose
    private String Key;

    /**
    * 类型
    */
    @SerializedName("Type")
    @Expose
    private String Type;

    /**
    * 数量
    */
    @SerializedName("Count")
    @Expose
    private Long Count;

    /**
     * Get 热Key 
     * @return Key 热Key
     */
    public String getKey() {
        return this.Key;
    }

    /**
     * Set 热Key
     * @param Key 热Key
     */
    public void setKey(String Key) {
        this.Key = Key;
    }

    /**
     * Get 类型 
     * @return Type 类型
     */
    public String getType() {
        return this.Type;
    }

    /**
     * Set 类型
     * @param Type 类型
     */
    public void setType(String Type) {
        this.Type = Type;
    }

    /**
     * Get 数量 
     * @return Count 数量
     */
    public Long getCount() {
        return this.Count;
    }

    /**
     * Set 数量
     * @param Count 数量
     */
    public void setCount(Long Count) {
        this.Count = Count;
    }

    public HotKeyInfo() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public HotKeyInfo(HotKeyInfo source) {
        if (source.Key != null) {
            this.Key = new String(source.Key);
        }
        if (source.Type != null) {
            this.Type = new String(source.Type);
        }
        if (source.Count != null) {
            this.Count = new Long(source.Count);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Key", this.Key);
        this.setParamSimple(map, prefix + "Type", this.Type);
        this.setParamSimple(map, prefix + "Count", this.Count);

    }
}

==> tencentcloud-sdk-java-3.1.920-sources.jar: com/tencentcloudapi/redis/v20180412/models/HotKeyInfo.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.redis.v20180412.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class HotKeyInfo extends AbstractModel {

    /**
    * 热 Key 的名称。
    */
    @SerializedName("Key")
    @Expose
    private String Key;

    /**
    * Key 类型。
    */
    @SerializedName("Type")
    @Expose
    private String Type;

    /**
    * 某段时间内热 Key 的访问次数
    */
    @SerializedName("Count")
    @Expose
    private Long Count;

    /**
     * Get 热 Key 的名称。 
     * @return Key 热 Key 的名称。
     */
    public String getKey() {
        return this.Key;
    }

    /**
     * Set 热 Key 的名称。
     * @param Key 热 Key 的名称。
     */
    public void setKey(String Key) {
        this.Key = Key;
    }

    /**
     * Get Key 类型。 
     * @return Type Key 类型。
     */
    public String getType() {
        return this.Type;
    }

    /**
     * Set Key 类型。
     * @param Type Key 类型。
     */
    public void setType(String Type) {
        this.Type = Type;
    }

    /**
     * Get 某段时间内热 Key 的访问次数 
     * @return Count 某段时间内热 Key 的访问次数
     */
    public Long getCount() {
        return this.Count;
    }

    /**
     * Set 某段时间内热 Key 的访问次数
     * @param Count 某段时间内热 Key 的访问次数
     */
    public void setCount(Long Count) {
        this.Count = Count;
    }

    public HotKeyInfo() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public HotKeyInfo(HotKeyInfo source) {
        if (source.Key != null) {
            this.Key = new String(source.Key);
        }
        if (source.Type != null) {
            this.Type = new String(source.Type);
        }
        if (source.Count != null) {
            this.Count = new Long(source.Count);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Key", this.Key);
        this.setParamSimple(map, prefix + "Type", this.Type);
        this.setParamSimple(map, prefix + "Count", this.Count);

    }
}
